@@ -18,16 +18,10 @@ EXCLUDE = (
     "cmd/dot/dot.c",
     "cmd/dot/dot_builtins.cpp",
     "cmd/edgepaint/edgepaintmain.c",
-    "cmd/gvedit/csettings.cpp",
     "cmd/gvedit/csettings.h",
     "cmd/gvedit/imageviewer.cpp",
     "cmd/gvedit/imageviewer.h",
-    "cmd/gvedit/main.cpp",
-    "cmd/gvedit/mainwindow.cpp",
-    "cmd/gvedit/mainwindow.h",
-    "cmd/gvedit/mdichild.cpp",
     "cmd/gvedit/mdichild.h",
-    "cmd/gvedit/ui_settings.h",
     "cmd/gvmap/cluster.c",
     "cmd/gvmap/country_graph_coloring.c",
     "cmd/gvmap/country_graph_coloring.h",
@@ -35,14 +29,12 @@ EXCLUDE = (
     "cmd/gvmap/make_map.c",
     "cmd/gvmap/make_map.h",
     "cmd/gvmap/power.c",
-    "cmd/gvpr/gvprmain.c",
     "cmd/mingle/minglemain.cpp",
     "cmd/smyrna/arcball.c",
     "cmd/smyrna/arcball.h",
     "cmd/smyrna/draw.c",
     "cmd/smyrna/draw.h",
     "cmd/smyrna/glexpose.c",
-    "cmd/smyrna/glexpose.h",
     "cmd/smyrna/glmotion.c",
     "cmd/smyrna/glmotion.h",
     "cmd/smyrna/gltemplate.c",
@@ -51,27 +43,20 @@ EXCLUDE = (
     "cmd/smyrna/gui/appmouse.c",
     "cmd/smyrna/gui/appmouse.h",
     "cmd/smyrna/gui/callbacks.c",
-    "cmd/smyrna/gui/callbacks.h",
     "cmd/smyrna/gui/datalistcallbacks.c",
-    "cmd/smyrna/gui/datalistcallbacks.h",
     "cmd/smyrna/gui/frmobjectui.c",
-    "cmd/smyrna/gui/frmobjectui.h",
     "cmd/smyrna/gui/glcompui.c",
     "cmd/smyrna/gui/glcompui.h",
     "cmd/smyrna/gui/gui.c",
     "cmd/smyrna/gui/gui.h",
     "cmd/smyrna/gui/menucallbacks.c",
-    "cmd/smyrna/gui/menucallbacks.h",
     "cmd/smyrna/gui/toolboxcallbacks.c",
-    "cmd/smyrna/gui/toolboxcallbacks.h",
     "cmd/smyrna/gui/topviewsettings.c",
-    "cmd/smyrna/gui/topviewsettings.h",
     "cmd/smyrna/gvprpipe.c",
     "cmd/smyrna/hier.c",
     "cmd/smyrna/hier.h",
     "cmd/smyrna/hotkeymap.c",
     "cmd/smyrna/hotkeymap.h",
-    "cmd/smyrna/main.c",
     "cmd/smyrna/polytess.c",
     "cmd/smyrna/polytess.h",
     "cmd/smyrna/selectionfuncs.c",
@@ -79,7 +64,6 @@ EXCLUDE = (
     "cmd/smyrna/smyrna_utils.c",
     "cmd/smyrna/smyrna_utils.h",
     "cmd/smyrna/smyrnadefs.h",
-    "cmd/smyrna/support.h",
     "cmd/smyrna/topfisheyeview.c",
     "cmd/smyrna/topfisheyeview.h",
     "cmd/smyrna/topviewfuncs.c",
@@ -92,17 +76,14 @@ EXCLUDE = (
     "cmd/smyrna/viewportcamera.h",
     "cmd/tools/acyclic.c",
     "cmd/tools/bcomps.c",
-    "cmd/tools/ccomps.c",
     "cmd/tools/colortbl.h",
     "cmd/tools/colxlate.c",
     "cmd/tools/convert.h",
     "cmd/tools/cvtgxl.c",
     "cmd/tools/dijkstra.c",
     "cmd/tools/gc.c",
-    "cmd/tools/gml2gv.c",
     "cmd/tools/gml2gv.h",
     "cmd/tools/graph_generator.c",
-    "cmd/tools/graph_generator.h",
     "cmd/tools/graphml2gv.c",
     "cmd/tools/gv2gml.c",
     "cmd/tools/gv2gxl.c",
@@ -110,7 +91,6 @@ EXCLUDE = (
     "cmd/tools/gvgen.c",
     "cmd/tools/gvpack.cpp",
     "cmd/tools/gxl2gv.c",
-    "cmd/tools/matrix_market.c",
     "cmd/tools/matrix_market.h",
     "cmd/tools/mm2gv.c",
     "cmd/tools/mmio.c",
@@ -119,7 +99,6 @@ EXCLUDE = (
     "cmd/tools/sccmap.c",
     "cmd/tools/tred.c",
     "cmd/tools/unflatten.c",
-    "contrib/diffimg/diffimg.c",
     "contrib/prune/prune.c",
     "doc/libgraph/agmemread.c",
     "doc/libgraph/sccmap.c",
@@ -128,50 +107,35 @@ EXCLUDE = (
     "lib/ast/chrtoi.c",
     "lib/ast/error.c",
     "lib/ast/error.h",
-    "lib/ast/fmtbuf.c",
     "lib/ast/fmtesc.c",
-    "lib/ast/pathaccess.c",
-    "lib/ast/pathcanon.c",
-    "lib/ast/pathcat.c",
-    "lib/ast/pathfind.c",
-    "lib/ast/pathpath.c",
-    "lib/ast/sfstr.h",
-    "lib/ast/strcopy.c",
     "lib/ast/stresc.c",
     "lib/ast/strmatch.c",
-    "lib/cdt/cdt.h",
     "lib/cdt/dtclose.c",
     "lib/cdt/dtdisc.c",
     "lib/cdt/dtextract.c",
     "lib/cdt/dtflatten.c",
     "lib/cdt/dthash.c",
     "lib/cdt/dthdr.h",
-    "lib/cdt/dtlist.c",
     "lib/cdt/dtmethod.c",
     "lib/cdt/dtopen.c",
     "lib/cdt/dtrenew.c",
     "lib/cdt/dtrestore.c",
     "lib/cdt/dtsize.c",
-    "lib/cdt/dtstat.c",
     "lib/cdt/dtstrhash.c",
     "lib/cdt/dttree.c",
     "lib/cdt/dtview.c",
-    "lib/cdt/dtwalk.c",
-    "lib/cgraph/agerror.c",
     "lib/cgraph/apply.c",
     "lib/cgraph/attr.c",
     "lib/cgraph/cghdr.h",
-    "lib/cgraph/cgraph.h",
     "lib/cgraph/edge.c",
-    "lib/cgraph/flatten.c",
     "lib/cgraph/graph.c",
     "lib/cgraph/id.c",
     "lib/cgraph/imap.c",
+    "lib/cgraph/ingraphs.c",
+    "lib/cgraph/ingraphs.h",
     "lib/cgraph/io.c",
-    "lib/cgraph/mem.c",
     "lib/cgraph/node.c",
     "lib/cgraph/obj.c",
-    "lib/cgraph/pend.c",
     "lib/cgraph/rec.c",
     "lib/cgraph/refstr.c",
     "lib/cgraph/subg.c",
@@ -202,7 +166,6 @@ EXCLUDE = (
     "lib/common/const.h",
     "lib/common/ellipse.c",
     "lib/common/emit.c",
-    "lib/common/entities.h",
     "lib/common/geom.c",
     "lib/common/geom.h",
     "lib/common/geomprocs.h",
@@ -213,12 +176,8 @@ EXCLUDE = (
     "lib/common/htmltable.c",
     "lib/common/htmltable.h",
     "lib/common/input.c",
-    "lib/common/intset.c",
-    "lib/common/intset.h",
     "lib/common/labels.c",
     "lib/common/macros.h",
-    "lib/common/memory.c",
-    "lib/common/memory.h",
     "lib/common/ns.c",
     "lib/common/output.c",
     "lib/common/pointset.c",
@@ -233,14 +192,10 @@ EXCLUDE = (
     "lib/common/taper.c",
     "lib/common/textspan.c",
     "lib/common/textspan.h",
-    "lib/common/timing.c",
     "lib/common/types.h",
     "lib/common/usershape.h",
     "lib/common/utils.c",
-    "lib/common/xml.c",
     "lib/dotgen/acyclic.c",
-    "lib/dotgen/aspect.c",
-    "lib/dotgen/aspect.h",
     "lib/dotgen/class1.c",
     "lib/dotgen/class2.c",
     "lib/dotgen/cluster.c",
@@ -250,7 +205,6 @@ EXCLUDE = (
     "lib/dotgen/dot.h",
     "lib/dotgen/dotinit.c",
     "lib/dotgen/dotprocs.h",
-    "lib/dotgen/dotsplines.c",
     "lib/dotgen/fastgr.c",
     "lib/dotgen/flat.c",
     "lib/dotgen/mincross.c",
@@ -258,7 +212,6 @@ EXCLUDE = (
     "lib/dotgen/rank.c",
     "lib/dotgen/sameport.c",
     "lib/edgepaint/edge_distinct_coloring.c",
-    "lib/edgepaint/edge_distinct_coloring.h",
     "lib/edgepaint/furtherest_point.c",
     "lib/edgepaint/furtherest_point.h",
     "lib/edgepaint/intersection.c",
@@ -266,9 +219,7 @@ EXCLUDE = (
     "lib/edgepaint/lab.c",
     "lib/edgepaint/lab.h",
     "lib/edgepaint/lab_gamut.c",
-    "lib/edgepaint/lab_gamut.h",
     "lib/edgepaint/node_distinct_coloring.c",
-    "lib/edgepaint/node_distinct_coloring.h",
     "lib/expr/excc.c",
     "lib/expr/excontext.c",
     "lib/expr/exdata.c",
@@ -280,7 +231,6 @@ EXCLUDE = (
     "lib/expr/exnospace.c",
     "lib/expr/exopen.c",
     "lib/expr/expr.h",
-    "lib/expr/exstash.c",
     "lib/expr/extoken.c",
     "lib/expr/extype.c",
     "lib/expr/exzero.c",
@@ -295,7 +245,6 @@ EXCLUDE = (
     "lib/fdpgen/grid.c",
     "lib/fdpgen/grid.h",
     "lib/fdpgen/layout.c",
-    "lib/fdpgen/tlayout.c",
     "lib/fdpgen/tlayout.h",
     "lib/fdpgen/xlayout.c",
     "lib/fdpgen/xlayout.h",
@@ -307,19 +256,15 @@ EXCLUDE = (
     "lib/glcomp/glcompimage.c",
     "lib/glcomp/glcompimage.h",
     "lib/glcomp/glcomplabel.c",
-    "lib/glcomp/glcomplabel.h",
     "lib/glcomp/glcompmouse.c",
     "lib/glcomp/glcompmouse.h",
     "lib/glcomp/glcomppanel.c",
-    "lib/glcomp/glcomppanel.h",
     "lib/glcomp/glcompset.c",
     "lib/glcomp/glcompset.h",
     "lib/glcomp/glcomptextpng.c",
-    "lib/glcomp/glcomptextpng.h",
     "lib/glcomp/glcomptexture.c",
     "lib/glcomp/glcomptexture.h",
     "lib/glcomp/glpangofont.c",
-    "lib/glcomp/glpangofont.h",
     "lib/glcomp/glutils.c",
     "lib/glcomp/glutils.h",
     "lib/gvc/gvc.c",
@@ -327,7 +272,6 @@ EXCLUDE = (
     "lib/gvc/gvcext.h",
     "lib/gvc/gvcint.h",
     "lib/gvc/gvcjob.h",
-    "lib/gvc/gvcommon.h",
     "lib/gvc/gvconfig.c",
     "lib/gvc/gvconfig.h",
     "lib/gvc/gvcontext.c",
@@ -348,37 +292,24 @@ EXCLUDE = (
     "lib/gvc/gvrender.c",
     "lib/gvc/gvtextlayout.c",
     "lib/gvc/gvtool_tred.c",
-    "lib/gvc/gvusershape.c",
-    "lib/gvpr/actions.c",
     "lib/gvpr/actions.h",
-    "lib/gvpr/compile.c",
     "lib/gvpr/compile.h",
     "lib/gvpr/gdefs.h",
     "lib/gvpr/gprstate.c",
     "lib/gvpr/gprstate.h",
-    "lib/gvpr/gvpr.c",
     "lib/gvpr/gvpr.h",
-    "lib/gvpr/parse.c",
     "lib/gvpr/parse.h",
-    "lib/gvpr/queue.c",
-    "lib/gvpr/queue.h",
     "lib/gvpr/trie.c",
     "lib/gvpr/trieFA.h",
-    "lib/ingraphs/ingraphs.c",
-    "lib/ingraphs/ingraphs.h",
     "lib/label/index.c",
     "lib/label/index.h",
     "lib/label/node.c",
     "lib/label/node.h",
-    "lib/label/nrtmain.c",
     "lib/label/rectangle.c",
-    "lib/label/rectangle.h",
     "lib/label/split.q.c",
     "lib/label/split.q.h",
-    "lib/label/xlabels.c",
     "lib/label/xlabels.h",
     "lib/mingle/agglomerative_bundling.cpp",
-    "lib/mingle/agglomerative_bundling.h",
     "lib/mingle/edge_bundling.cpp",
     "lib/mingle/edge_bundling.h",
     "lib/mingle/ink.cpp",
@@ -387,13 +318,10 @@ EXCLUDE = (
     "lib/mingle/nearest_neighbor_graph_ann.cpp",
     "lib/neatogen/adjust.c",
     "lib/neatogen/adjust.h",
-    "lib/neatogen/bfs.c",
-    "lib/neatogen/bfs.h",
     "lib/neatogen/call_tri.c",
     "lib/neatogen/call_tri.h",
     "lib/neatogen/circuit.c",
     "lib/neatogen/closest.c",
-    "lib/neatogen/closest.h",
     "lib/neatogen/compute_hierarchy.c",
     "lib/neatogen/conjgrad.c",
     "lib/neatogen/conjgrad.h",
@@ -405,20 +333,16 @@ EXCLUDE = (
     "lib/neatogen/delaunay.h",
     "lib/neatogen/digcola.h",
     "lib/neatogen/dijkstra.c",
-    "lib/neatogen/dijkstra.h",
     "lib/neatogen/edges.c",
     "lib/neatogen/edges.h",
     "lib/neatogen/embed_graph.c",
-    "lib/neatogen/embed_graph.h",
     "lib/neatogen/fPQ.h",
     "lib/neatogen/geometry.c",
     "lib/neatogen/geometry.h",
     "lib/neatogen/heap.c",
-    "lib/neatogen/heap.h",
     "lib/neatogen/hedges.c",
     "lib/neatogen/hedges.h",
     "lib/neatogen/info.c",
-    "lib/neatogen/info.h",
     "lib/neatogen/kkutils.c",
     "lib/neatogen/kkutils.h",
     "lib/neatogen/legal.c",
@@ -426,8 +350,6 @@ EXCLUDE = (
     "lib/neatogen/matinv.c",
     "lib/neatogen/matrix_ops.c",
     "lib/neatogen/matrix_ops.h",
-    "lib/neatogen/mem.h",
-    "lib/neatogen/memory.c",
     "lib/neatogen/multispline.c",
     "lib/neatogen/multispline.h",
     "lib/neatogen/neato.h",
@@ -438,34 +360,27 @@ EXCLUDE = (
     "lib/neatogen/overlap.c",
     "lib/neatogen/overlap.h",
     "lib/neatogen/pca.c",
-    "lib/neatogen/pca.h",
     "lib/neatogen/poly.c",
     "lib/neatogen/poly.h",
-    "lib/neatogen/printvis.c",
     "lib/neatogen/quad_prog_solve.c",
     "lib/neatogen/quad_prog_solver.h",
     "lib/neatogen/quad_prog_vpsc.c",
     "lib/neatogen/quad_prog_vpsc.h",
     "lib/neatogen/randomkit.c",
     "lib/neatogen/randomkit.h",
-    "lib/neatogen/sgd.c",
     "lib/neatogen/sgd.h",
     "lib/neatogen/site.c",
-    "lib/neatogen/site.h",
     "lib/neatogen/smart_ini_x.c",
-    "lib/neatogen/solve.c",
     "lib/neatogen/sparsegraph.h",
     "lib/neatogen/stress.c",
     "lib/neatogen/stress.h",
     "lib/neatogen/stuff.c",
     "lib/neatogen/voronoi.c",
-    "lib/neatogen/voronoi.h",
     "lib/ortho/fPQ.c",
     "lib/ortho/fPQ.h",
     "lib/ortho/maze.c",
     "lib/ortho/maze.h",
     "lib/ortho/ortho.c",
-    "lib/ortho/ortho.h",
     "lib/ortho/partition.c",
     "lib/ortho/rawgraph.c",
     "lib/ortho/rawgraph.h",
@@ -476,8 +391,6 @@ EXCLUDE = (
     "lib/ortho/trapezoid.c",
     "lib/osage/osage.h",
     "lib/osage/osageinit.c",
-    "lib/pack/ccomps.c",
-    "lib/pack/pack.c",
     "lib/pack/pack.h",
     "lib/patchwork/patchwork.c",
     "lib/patchwork/patchwork.h",
@@ -485,16 +398,13 @@ EXCLUDE = (
     "lib/patchwork/tree_map.c",
     "lib/patchwork/tree_map.h",
     "lib/pathplan/cvt.c",
-    "lib/pathplan/inpoly.c",
     "lib/pathplan/pathgeom.h",
     "lib/pathplan/pathplan.h",
-    "lib/pathplan/pathutil.h",
     "lib/pathplan/route.c",
     "lib/pathplan/shortest.c",
     "lib/pathplan/shortestpth.c",
     "lib/pathplan/solvers.c",
     "lib/pathplan/solvers.h",
-    "lib/pathplan/tri.h",
     "lib/pathplan/triang.c",
     "lib/pathplan/util.c",
     "lib/pathplan/vis.h",
@@ -504,62 +414,23 @@ EXCLUDE = (
     "lib/rbtree/red_black_tree.h",
     "lib/rbtree/test_red_black_tree.c",
     "lib/sfdpgen/Multilevel.c",
-    "lib/sfdpgen/Multilevel.h",
     "lib/sfdpgen/post_process.c",
     "lib/sfdpgen/post_process.h",
     "lib/sfdpgen/sfdp.h",
     "lib/sfdpgen/sfdpinit.c",
-    "lib/sfdpgen/sfdpinternal.h",
     "lib/sfdpgen/sparse_solve.c",
-    "lib/sfdpgen/sparse_solve.h",
     "lib/sfdpgen/spring_electrical.c",
     "lib/sfdpgen/spring_electrical.h",
-    "lib/sfdpgen/stress_model.c",
-    "lib/sfdpgen/stress_model.h",
-    "lib/sfio/Sfio_f/_sffileno.c",
-    "lib/sfio/Sfio_f/_sfgetc.c",
-    "lib/sfio/Sfio_f/_sfputc.c",
     "lib/sfio/Sfio_f/_sfslen.c",
-    "lib/sfio/sfclose.c",
     "lib/sfio/sfcvt.c",
-    "lib/sfio/sfdisc.c",
-    "lib/sfio/sfexcept.c",
     "lib/sfio/sfextern.c",
-    "lib/sfio/sffilbuf.c",
-    "lib/sfio/sfflsbuf.c",
     "lib/sfio/sfhdr.h",
     "lib/sfio/sfio.h",
-    "lib/sfio/sfio_t.h",
-    "lib/sfio/sfmode.c",
-    "lib/sfio/sfnew.c",
-    "lib/sfio/sfnputc.c",
-    "lib/sfio/sfopen.c",
-    "lib/sfio/sfpkrd.c",
-    "lib/sfio/sfprintf.c",
-    "lib/sfio/sfputr.c",
-    "lib/sfio/sfraise.c",
-    "lib/sfio/sfrd.c",
-    "lib/sfio/sfread.c",
-    "lib/sfio/sfscanf.c",
-    "lib/sfio/sfseek.c",
-    "lib/sfio/sfsetbuf.c",
-    "lib/sfio/sfsetfd.c",
-    "lib/sfio/sfsk.c",
-    "lib/sfio/sfstack.c",
-    "lib/sfio/sfswap.c",
-    "lib/sfio/sfsync.c",
     "lib/sfio/sftable.c",
-    "lib/sfio/sfungetc.c",
-    "lib/sfio/sfvprintf.c",
+    "lib/sfio/sfprint.c",
     "lib/sfio/sfvscanf.c",
-    "lib/sfio/sfwr.c",
-    "lib/sfio/sfwrite.c",
-    "lib/sparse/BinaryHeap.c",
-    "lib/sparse/BinaryHeap.h",
     "lib/sparse/DotIO.c",
     "lib/sparse/DotIO.h",
-    "lib/sparse/LinkedList.c",
-    "lib/sparse/LinkedList.h",
     "lib/sparse/QuadTree.c",
     "lib/sparse/QuadTree.h",
     "lib/sparse/SparseMatrix.c",
@@ -578,13 +449,6 @@ EXCLUDE = (
     "lib/twopigen/circle.c",
     "lib/twopigen/circle.h",
     "lib/twopigen/twopiinit.c",
-    "lib/vmalloc/test.c",
-    "lib/vmalloc/vmalloc.c",
-    "lib/vmalloc/vmalloc.h",
-    "lib/vmalloc/vmclear.c",
-    "lib/vmalloc/vmclose.c",
-    "lib/vmalloc/vmopen.c",
-    "lib/vmalloc/vmstrdup.c",
     "lib/vpsc/block.cpp",
     "lib/vpsc/block.h",
     "lib/vpsc/blocks.cpp",
@@ -595,25 +459,31 @@ EXCLUDE = (
     "lib/vpsc/csolve_VPSC.h",
     "lib/vpsc/generate-constraints.cpp",
     "lib/vpsc/generate-constraints.h",
-    "lib/vpsc/pairingheap/PairingHeap.cpp",
-    "lib/vpsc/pairingheap/PairingHeap.h",
-    "lib/vpsc/pairingheap/dsexceptions.h",
     "lib/vpsc/solve_VPSC.cpp",
     "lib/vpsc/solve_VPSC.h",
     "lib/vpsc/variable.cpp",
     "lib/vpsc/variable.h",
-    "lib/xdot/xdot.c",
-    "lib/xdot/xdot.h",
     "macosx/GVApplicationDelegate.h",
+    "macosx/GVApplicationDelegate.m",
     "macosx/GVAttributeInspectorController.h",
+    "macosx/GVAttributeInspectorController.m",
     "macosx/GVAttributeSchema.h",
+    "macosx/GVAttributeSchema.m",
     "macosx/GVDocument.h",
+    "macosx/GVDocument.m",
     "macosx/GVExportViewController.h",
+    "macosx/GVExportViewController.m",
     "macosx/GVFileNotificationCenter.h",
+    "macosx/GVFileNotificationCenter.m",
     "macosx/GVGraphArguments.h",
+    "macosx/GVGraphArguments.m",
     "macosx/GVGraphDefaultAttributes.h",
+    "macosx/GVGraphDefaultAttributes.m",
     "macosx/GVWindowController.h",
+    "macosx/GVWindowController.m",
     "macosx/GVZGraph.h",
+    "macosx/GVZGraph.m",
+    "macosx/main.m",
     "plugin.demo/xgtk/src/callbacks.c",
     "plugin.demo/xgtk/src/callbacks.h",
     "plugin.demo/xgtk/src/gvdevice_xgtk.c",
@@ -628,14 +498,12 @@ EXCLUDE = (
     "plugin/core/gvrender_core_fig.c",
     "plugin/core/gvrender_core_json.c",
     "plugin/core/gvrender_core_map.c",
-    "plugin/core/gvrender_core_mp.c",
     "plugin/core/gvrender_core_pic.c",
     "plugin/core/gvrender_core_pov.c",
     "plugin/core/gvrender_core_ps.c",
     "plugin/core/gvrender_core_svg.c",
     "plugin/core/gvrender_core_tk.c",
     "plugin/devil/gvdevice_devil.c",
-    "plugin/devil/gvplugin_devil.c",
     "plugin/dot_layout/gvlayout_dot_layout.c",
     "plugin/dot_layout/gvplugin_dot_layout.c",
     "plugin/gd/gvdevice_gd.c",
@@ -644,8 +512,6 @@ EXCLUDE = (
     "plugin/gd/gvrender_gd.c",
     "plugin/gd/gvrender_gd_vrml.c",
     "plugin/gd/gvtextlayout_gd.c",
-    "plugin/gdiplus/FileStream.cpp",
-    "plugin/gdiplus/FileStream.h",
     "plugin/gdiplus/gvdevice_gdiplus.cpp",
     "plugin/gdiplus/gvloadimage_gdiplus.cpp",
     "plugin/gdiplus/gvplugin_gdiplus.cpp",
@@ -654,31 +520,16 @@ EXCLUDE = (
     "plugin/gdiplus/gvtextlayout_gdiplus.cpp",
     "plugin/gdk/gvdevice_gdk.c",
     "plugin/gdk/gvloadimage_gdk.c",
-    "plugin/gdk/gvplugin_gdk.c",
     "plugin/gs/gvloadimage_gs.c",
-    "plugin/gs/gvplugin_gs.c",
-    "plugin/gtk/callbacks.c",
-    "plugin/gtk/callbacks.h",
-    "plugin/gtk/gvdevice_gtk.c",
-    "plugin/gtk/gvplugin_gtk.c",
-    "plugin/gtk/interface.c",
-    "plugin/gtk/interface.h",
-    "plugin/gtk/support.c",
-    "plugin/gtk/support.h",
-    "plugin/lasi/gvloadimage_lasi.c",
-    "plugin/lasi/gvplugin_lasi.c",
     "plugin/lasi/gvrender_lasi.cpp",
-    "plugin/neato_layout/gvlayout_neato_layout.c",
-    "plugin/neato_layout/gvplugin_neato_layout.c",
     "plugin/pango/gvgetfontlist.h",
-    "plugin/pango/gvgetfontlist_pango.c",
     "plugin/pango/gvloadimage_pango.c",
     "plugin/pango/gvplugin_pango.c",
     "plugin/pango/gvrender_pango.c",
     "plugin/pango/gvtextlayout_pango.c",
     "plugin/poppler/gvloadimage_poppler.c",
-    "plugin/poppler/gvplugin_poppler.c",
     "plugin/quartz/GVTextLayout.h",
+    "plugin/quartz/GVTextLayout.m",
     "plugin/quartz/gvdevice_quartz.c",
     "plugin/quartz/gvloadimage_quartz.c",
     "plugin/quartz/gvplugin_quartz.c",
@@ -690,56 +541,24 @@ EXCLUDE = (
     "plugin/webp/gvdevice_webp.c",
     "plugin/webp/gvloadimage_webp.c",
     "plugin/webp/gvplugin_webp.c",
-    "plugin/xlib/gvdevice_xlib.c",
-    "plugin/xlib/gvplugin_xlib.c",
-    "tclpkg/gdtclft/gdtclft.c",
-    "tclpkg/gv/gv.cpp",
     "tclpkg/gv/gv_builtins.c",
     "tclpkg/gv/gv_dummy_init.c",
     "tclpkg/gv/gv_java_init.c",
     "tclpkg/gv/gv_php_init.c",
     "tclpkg/gv/gv_tcl_init.c",
     "tclpkg/tcldot/no_builtins.c",
-    "tclpkg/tcldot/tcldot-edgecmd.c",
-    "tclpkg/tcldot/tcldot-graphcmd.c",
     "tclpkg/tcldot/tcldot-id.c",
     "tclpkg/tcldot/tcldot-io.c",
-    "tclpkg/tcldot/tcldot-nodecmd.c",
     "tclpkg/tcldot/tcldot-util.c",
-    "tclpkg/tcldot/tcldot.c",
     "tclpkg/tcldot/tcldot.h",
-    "tclpkg/tcldot/tcldot_builtins.c",
-    "tclpkg/tclhandle/tclhandle.c",
-    "tclpkg/tclhandle/tclhandle.h",
+    "tclpkg/tcldot/tcldot_builtins.cpp",
     "tclpkg/tclpathplan/find_ints.c",
     "tclpkg/tclpathplan/intersect.c",
     "tclpkg/tclpathplan/makecw.c",
     "tclpkg/tclpathplan/simple.h",
     "tclpkg/tclpathplan/tclpathplan.c",
     "tclpkg/tclpathplan/wrapper.c",
-    "tclpkg/tclstubs/tclInt.h",
     "tclpkg/tclstubs/tclStubLib.c",
-    "tclpkg/tkspline/dllEntry.c",
-    "tclpkg/tkspline/tkspline.c",
-    "tclpkg/tkstubs/tkInt.h",
-    "tclpkg/tkstubs/tkStubImg.c",
-    "tclpkg/tkstubs/tkStubLib.c",
-    "tests/check-package-version.c",
-    "tests/unit_tests/lib/common/command_line.c",
-    "windows/gvedit/Application.h",
-    "windows/gvedit/GraphX.cpp",
-    "windows/gvedit/UAbout.cpp",
-    "windows/gvedit/UAbout.h",
-    "windows/gvedit/UEditor.cpp",
-    "windows/gvedit/UEditor.h",
-    "windows/gvedit/UPreProcess.cpp",
-    "windows/gvedit/UPreProcess.h",
-    "windows/gvedit/UPreview.cpp",
-    "windows/gvedit/UPreview.h",
-    "windows/gvedit/USettings.cpp",
-    "windows/gvedit/USettings.h",
-    "windows/gvedit/Umain.cpp",
-    "windows/gvedit/Umain.h",
     "windows/include/unistd/unistd.h",
 )
 
@@ -767,21 +586,22 @@ sources = subprocess.check_output(
         "**/*.c++",
         "**/*.cxx",
         "**/*.cc",
+        "**/*.m",
     ],
-    universal_newlines=True,
+    text=True,
 )
 
+ret = 0
 for source in sources.split("\x00")[:-1]:
-
     print(f"checking {source}...")
 
     original = Path(source).read_text(encoding="utf-8")
 
     # ask `clang-format` to style the file
     reformatted = subprocess.check_output(
-        ["clang-format", "--style=file", "--", source],
+        ["clang-format-19", "--style=file", "--", source],
         cwd=root,
-        universal_newlines=True,
+        text=True,
     )
 
     if source in EXCLUDE:
@@ -803,4 +623,6 @@ for source in sources.split("\x00")[:-1]:
     )
     if diff:
         print(f"{source} incorrectly formatted:\n{''.join(diff)}", end="")
-        sys.exit(-1)
+        ret = -1
+
+sys.exit(ret)
