@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -13,8 +13,8 @@
 #include "smyrnadefs.h"
 
     extern glCompSet *glcreate_gl_topview_menu(void);
-    extern void switch2D3D(glCompObj *obj, GLfloat x, GLfloat y, glMouseButtonType t);
-    extern void menu_click_center(glCompObj *obj, GLfloat x, GLfloat y, glMouseButtonType t);
-    extern void menu_click_zoom_minus(glCompObj *obj, GLfloat x, GLfloat y, glMouseButtonType t);
-    extern void menu_click_zoom_plus(glCompObj *obj, GLfloat x, GLfloat y, glMouseButtonType t);
-    extern void menu_click_pan(glCompObj *obj, GLfloat x, GLfloat y, glMouseButtonType t);
+void switch2D3D(glCompObj *obj, float x, float y, glMouseButtonType t);
+void menu_click_center(glCompObj *obj, float x, float y, glMouseButtonType t);
+void menu_click_zoom_minus(glCompObj *obj, float x, float y, glMouseButtonType t);
+void menu_click_zoom_plus(glCompObj *obj, float x, float y, glMouseButtonType t);
+void menu_click_pan(glCompObj *obj, float x, float y, glMouseButtonType t);
