@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -11,6 +11,7 @@
 #pragma once
 
 #include <stdbool.h>
+#include <stddef.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -53,7 +54,7 @@ extern "C" {
     NEATOPROCS_API void free_scan_graph(graph_t *);
     NEATOPROCS_API int setSeed (graph_t*, int dflt, long* seedp);
     NEATOPROCS_API void shortest_path(graph_t *, int);
-    NEATOPROCS_API void solve(double *, double *, double *, int);
+    NEATOPROCS_API void solve(double *, double *, double *, size_t);
     NEATOPROCS_API void solve_model(graph_t *, int);
     NEATOPROCS_API int solveCircuit(int nG, double **Gm, double **Gm_inv);
     NEATOPROCS_API void spline_edges(Agraph_t *);
@@ -64,7 +65,7 @@ extern "C" {
     NEATOPROCS_API void neato_translate(Agraph_t * g);
     NEATOPROCS_API bool neato_set_aspect(graph_t * g);
     NEATOPROCS_API void toggle(int);
-    NEATOPROCS_API int user_pos(Agsym_t *, Agsym_t *, Agnode_t *, int);
+    NEATOPROCS_API bool user_pos(Agsym_t *, Agsym_t *, Agnode_t *, int);
     NEATOPROCS_API double **new_array(int i, int j, double val);
     NEATOPROCS_API void free_array(double **rv);
     NEATOPROCS_API int matinv(double **A, double **Ainv, int n);
