@@ -1,15 +1,14 @@
 #include <algorithm>
 #include <cassert>
 #include <cmath>
+#include <format>
 #include <limits>
 #include <stdexcept>
 
-#include <fmt/format.h>
-
 #include "svg_element.h"
-#include <cgraph/unreachable.h>
+#include <util/unreachable.h>
 
-SVG::SVGElement::SVGElement(SVGElementType type) : type(type) {}
+SVG::SVGElement::SVGElement(SVGElementType etype) : elem_type(etype) {}
 
 static double px_to_pt(double px) {
   // a `pt` is 0.75 `px`. See e.g.
@@ -18,7 +17,7 @@ static double px_to_pt(double px) {
 }
 
 bool SVG::SVGElement::is_closed_shape_element() const {
-  switch (type) {
+  switch (elem_type) {
   case SVG::SVGElementType::Circle:
   case SVG::SVGElementType::Ellipse:
   case SVG::SVGElementType::Polygon:
@@ -30,7 +29,7 @@ bool SVG::SVGElement::is_closed_shape_element() const {
 }
 
 bool SVG::SVGElement::is_shape_element() const {
-  switch (type) {
+  switch (elem_type) {
   case SVG::SVGElementType::Circle:
   case SVG::SVGElementType::Ellipse:
   case SVG::SVGElementType::Line:
@@ -76,8 +75,8 @@ static std::string rgb_to_hex(const std::string &color, double opacity = 1.0) {
   const auto b = std::stoi(color.substr(comma2 + 1, close_par - 1));
   const auto opacity_int = std::lround(opacity * 255.0);
   const auto opacity_hex_str =
-      opacity_int < 255 ? fmt::format("{:02x}", opacity_int) : "";
-  return fmt::format("#{:02x}{:02x}{:02x}{}", r, g, b, opacity_hex_str);
+      opacity_int < 255 ? std::format("{:02x}", opacity_int) : "";
+  return std::format("#{:02x}{:02x}{:02x}{}", r, g, b, opacity_hex_str);
 }
 
 // convert a valid color specification to the flavor that Graphviz uses in the
@@ -102,7 +101,7 @@ std::string SVG::to_dot_color(const std::string &color, double opacity) {
   }
   if (opacity < 1.0) {
     if (!color.starts_with("rgb")) {
-      throw std::runtime_error{fmt::format(
+      throw std::runtime_error{std::format(
           "Cannot convert stroke={}, stroke_opacity={} to Graphviz color",
           color, opacity)};
     }
@@ -154,9 +153,9 @@ SVG::SVGRect SVG::SVGElement::bbox(bool throw_if_bbox_not_defined) {
               .y = std::numeric_limits<double>::max() / 2,
               .width = std::numeric_limits<double>::lowest(),
               .height = std::numeric_limits<double>::lowest()};
-    switch (type) {
+    switch (elem_type) {
     case SVG::SVGElementType::Group:
-      // SVG group bounding box is detemined solely by its children
+      // SVG group bounding box is determined solely by its children
       break;
     case SVG::SVGElementType::Ellipse: {
       m_bbox = {
@@ -204,7 +203,7 @@ SVG::SVGRect SVG::SVGElement::bbox(bool throw_if_bbox_not_defined) {
       break;
     default:
       throw std::runtime_error{
-          fmt::format("Unhandled svg element type {}", tag(type))};
+          std::format("Unhandled svg element type {}", tag(elem_type))};
     }
 
     const auto throw_if_child_bbox_is_not_defined = false;
@@ -227,9 +226,9 @@ SVG::SVGRect SVG::SVGElement::outline_bbox(bool throw_if_bbox_not_defined) {
             .y = std::numeric_limits<double>::max() / 2,
             .width = std::numeric_limits<double>::lowest(),
             .height = std::numeric_limits<double>::lowest()};
-  switch (type) {
+  switch (elem_type) {
   case SVG::SVGElementType::Group:
-    // SVG group bounding box is detemined solely by its children
+    // SVG group bounding box is determined solely by its children
     break;
   case SVG::SVGElementType::Ellipse: {
     const auto stroke_width = (attributes.rx == 0 && attributes.ry == 0)
@@ -279,15 +278,17 @@ SVG::SVGRect SVG::SVGElement::outline_bbox(bool throw_if_bbox_not_defined) {
       // there is always a next point since we iterate only to the next to
       // last point
       const auto &next_point = *std::next(it);
-      const SVG::SVGPoint miter_point =
+      const SVG::SVGPoints miter_shape =
           clockwise ?
                     // Graphviz draws some polygons clockwise and some
                     // counter-clockwise.
-              SVGElement::miter_point(prev_point, point, next_point)
+              SVGElement::miter_shape(prev_point, point, next_point)
                     :
                     // the SVG spec assumes clockwise so we swap the points
-              SVGElement::miter_point(next_point, point, prev_point);
-      m_bbox->extend(miter_point);
+              SVGElement::miter_shape(next_point, point, prev_point);
+      for (const auto &p : miter_shape) {
+        m_bbox->extend(p);
+      }
     }
     break;
   }
@@ -326,7 +327,116 @@ SVG::SVGRect SVG::SVGElement::outline_bbox(bool throw_if_bbox_not_defined) {
         }
         break;
       }
-      // FIXME: this throws for the `curve` and `icurve` edge arrows
+      const std::size_t num_points_in_curve_arrow_shape_path = 4;
+      if (path_points.size() == num_points_in_curve_arrow_shape_path) {
+        const auto horizontal_start = path_points[0].x;
+        const auto horizontal_control1 = path_points[1].x;
+        const auto horizontal_control2 = path_points[2].x;
+        const auto horizontal_end = path_points[3].x;
+
+        const auto vertical_start = path_points[0].y;
+        const auto vertical_control1 = path_points[1].y;
+        const auto vertical_control2 = path_points[2].y;
+        const auto vertical_end = path_points[3].y;
+
+        const auto has_horizontally_symmetric_control_points =
+            horizontal_start - horizontal_control1 ==
+            horizontal_control2 - horizontal_end;
+
+        const auto has_vertically_symmetric_control_points =
+            vertical_start - vertical_control1 ==
+            vertical_control2 - vertical_end;
+
+        const auto is_horizontally_mirrored =
+            horizontal_start == horizontal_end &&
+            horizontal_control1 == horizontal_control2 &&
+            has_vertically_symmetric_control_points;
+
+        const auto is_vertically_mirrored =
+            vertical_start == vertical_end &&
+            vertical_control1 == vertical_control2 &&
+            has_horizontally_symmetric_control_points;
+
+        if (is_horizontally_mirrored || is_vertically_mirrored) {
+          // A bezier curve which is either vertically or horizontally mirrored
+          // is flat at the center and has a negligible extension "backwards" at
+          // the start and end points. The Graphviz arrow shape `curve`, which
+          // is a cubic Bezier approximation of a semicircle, is a special case
+          // of this. A vertical edge with a `curve` arrow head is vertically
+          // mirrored and a horizontal edge with a `curve` arrow head is
+          // horizontally mirrored.
+          {
+            const auto horizontal_endpoint_extension =
+                is_vertically_mirrored ? attributes.stroke_width / 2 : 0;
+            const auto vertical_endpoint_extension =
+                is_horizontally_mirrored ? attributes.stroke_width / 2 : 0;
+            const auto num_intermediate_control_points = 2;
+            for (std::size_t i = 0; i < path_points.size();
+                 i += num_intermediate_control_points + 1) {
+              const auto &point = path_points[i];
+              const SVG::SVGRect point_bbox = {
+                  .x = point.x - horizontal_endpoint_extension,
+                  .y = point.y - vertical_endpoint_extension,
+                  .width = horizontal_endpoint_extension * 2,
+                  .height = vertical_endpoint_extension * 2,
+              };
+              m_bbox->extend(point_bbox);
+            }
+            const SVGPoint midpoint = cubic_bezier(0.5);
+            const SVG::SVGRect point_bbox = {
+                .x = midpoint.x - attributes.stroke_width / 2,
+                .y = midpoint.y - attributes.stroke_width / 2,
+                .width = attributes.stroke_width,
+                .height = attributes.stroke_width,
+            };
+            m_bbox->extend(point_bbox);
+          }
+          break;
+        }
+        const auto xmin = std::min(horizontal_start, horizontal_end);
+        const auto xmax = std::max(horizontal_start, horizontal_end);
+        const auto ymin = std::min(vertical_start, vertical_end);
+        const auto ymax = std::max(vertical_start, vertical_end);
+        if (horizontal_control1 >= xmin && horizontal_control1 <= xmax &&
+            horizontal_control2 >= xmin && horizontal_control2 <= xmax &&
+            vertical_control1 >= ymin && vertical_control1 <= ymax &&
+            vertical_control2 >= ymin && vertical_control2 <= ymax) {
+          // the control points are within a bounding box defined by the start
+          // and end points. This means that the Bezier curve is completely
+          // contained within this box, except for the extension caused by the
+          // stroke width. This extension can be calculated using the angle at
+          // the start and end points which is given by the closest control
+          // point. The Graphviz arrow shapes `rcurve`, `lcurve`, `ricurve` and
+          // `licurve` fulfills this condition.
+          const auto start_dx = horizontal_start - horizontal_control1;
+          const auto start_dy = vertical_start - vertical_control1;
+          const auto start_hypot = std::hypot(start_dx, start_dy);
+          const auto start_cos = start_dx / start_hypot;
+          const auto start_sin = start_dy / start_hypot;
+          const SVG::SVGPoint start_extension_left = {
+              horizontal_start + attributes.stroke_width / 2 * start_sin,
+              vertical_start - attributes.stroke_width / 2 * start_cos};
+          const SVG::SVGPoint start_extension_right = {
+              horizontal_start - attributes.stroke_width / 2 * start_sin,
+              vertical_start + attributes.stroke_width / 2 * start_cos};
+          m_bbox->extend(start_extension_left);
+          m_bbox->extend(start_extension_right);
+          const auto end_dx = horizontal_end - horizontal_control2;
+          const auto end_dy = vertical_end - vertical_control2;
+          const auto end_hypot = std::hypot(end_dx, end_dy);
+          const auto end_cos = end_dx / end_hypot;
+          const auto end_sin = end_dy / end_hypot;
+          const SVG::SVGPoint end_extension_left = {
+              horizontal_end + attributes.stroke_width / 2 * end_sin,
+              vertical_end + -attributes.stroke_width / 2 * end_cos};
+          const SVG::SVGPoint end_extension_right = {
+              horizontal_end + -attributes.stroke_width / 2 * end_sin,
+              vertical_end + attributes.stroke_width / 2 * end_cos};
+          m_bbox->extend(end_extension_left);
+          m_bbox->extend(end_extension_right);
+          break;
+        }
+      }
       throw std::runtime_error(
           "paths other than straight vertical, straight horizontal or the "
           "cylinder special case are currently not supported");
@@ -416,13 +526,15 @@ SVG::SVGRect SVG::SVGElement::outline_bbox(bool throw_if_bbox_not_defined) {
         // there is always a next point since we iterate only to the next to
         // last point
         const auto &next_point = *std::next(it);
-        const SVG::SVGPoint miter_point =
+        SVG::SVGPoints miter_shape =
             // Graphviz draws some polylines clockwise and some
             // counter-clockwise.
-            clockwise ? SVGElement::miter_point(prev_point, point, next_point) :
+            clockwise ? SVGElement::miter_shape(prev_point, point, next_point) :
                       // `miter_point` assumes clockwise so we swap the points
-                SVGElement::miter_point(next_point, point, prev_point);
-        m_bbox->extend(miter_point);
+                SVGElement::miter_shape(next_point, point, prev_point);
+        for (const auto &p : miter_shape) {
+          m_bbox->extend(p);
+        }
       }
     }
     break;
@@ -446,7 +558,7 @@ SVG::SVGRect SVG::SVGElement::outline_bbox(bool throw_if_bbox_not_defined) {
     break;
   default:
     throw std::runtime_error{
-        fmt::format("Unhandled svg element type {}", tag(type))};
+        std::format("Unhandled svg element type {}", tag(elem_type))};
   }
 
   const auto throw_if_child_bbox_is_not_defined = false;
@@ -459,11 +571,11 @@ SVG::SVGRect SVG::SVGElement::outline_bbox(bool throw_if_bbox_not_defined) {
   return *m_bbox;
 }
 
-SVG::SVGElement &SVG::SVGElement::find_child(const SVG::SVGElementType type,
+SVG::SVGElement &SVG::SVGElement::find_child(const SVG::SVGElementType etype,
                                              std::size_t index) {
   std::size_t i = 0;
   for (auto &child : children) {
-    if (child.type == type) {
+    if (child.elem_type == etype) {
       if (i == index) {
         return child;
       }
@@ -471,20 +583,20 @@ SVG::SVGElement &SVG::SVGElement::find_child(const SVG::SVGElementType type,
     }
   }
   throw std::runtime_error(
-      fmt::format("SVG element only has {} \"{}\" children, index {} not found",
-                  i, tag(type), index));
+      std::format("SVG element only has {} \"{}\" children, index {} not found",
+                  i, tag(etype), index));
 }
 
 SVG::SVGRect SVG::SVGElement::text_bbox() const {
-  assert(type == SVG::SVGElementType::Text && "Not a 'text' element");
+  assert(elem_type == SVG::SVGElementType::Text && "Not a 'text' element");
 
   if (attributes.font_family != "Courier,monospace") {
     throw std::runtime_error(
-        fmt::format("Cannot calculate bounding box for font \"{}\"",
+        std::format("Cannot calculate bounding box for font \"{}\"",
                     attributes.font_family));
   }
 
-  // Epirically determined font metrics for the Courier font
+  // Empirically determined font metrics for the Courier font
   const auto courier_width_per_pt = 0.6;
   const auto courier_height_per_pt = 1.2;
   const auto descent_per_pt = 0.257;
@@ -512,9 +624,49 @@ void SVG::SVGElement::append_attribute(std::string &output,
   output += attribute;
 }
 
+static double interpolate(double y0, double y1, double x) {
+  double dy = y1 - y0;
+
+  return y0 + x * dy;
+}
+
+// The cubic Bezier implementation is taken from
+// https://stackoverflow.com/a/37642695/3122101
+SVG::SVGPoint SVG::SVGElement::cubic_bezier(double t) {
+  assert(t >= 0);
+  assert(t <= 1);
+  assert(path_points.size() == 4);
+
+  const auto x0 = path_points[0].x;
+  const auto y0 = path_points[0].y;
+  const auto x1 = path_points[1].x;
+  const auto y1 = path_points[1].y;
+  const auto x2 = path_points[2].x;
+  const auto y2 = path_points[2].y;
+  const auto x3 = path_points[3].x;
+  const auto y3 = path_points[3].y;
+
+  const auto xa = interpolate(x0, x1, t);
+  const auto ya = interpolate(y0, y1, t);
+  const auto xb = interpolate(x1, x2, t);
+  const auto yb = interpolate(y1, y2, t);
+  const auto xc = interpolate(x2, x3, t);
+  const auto yc = interpolate(y2, y3, t);
+
+  const auto xm = interpolate(xa, xb, t);
+  const auto ym = interpolate(ya, yb, t);
+  const auto xn = interpolate(xb, xc, t);
+  const auto yn = interpolate(yb, yc, t);
+
+  const auto x = interpolate(xm, xn, t);
+  const auto y = interpolate(ym, yn, t);
+
+  return {x, y};
+}
+
 bool SVG::SVGElement::has_all_points_equal() const {
-  assert((type == SVG::SVGElementType::Polygon ||
-          type == SVG::SVGElementType::Polyline) &&
+  assert((elem_type == SVG::SVGElementType::Polygon ||
+          elem_type == SVG::SVGElementType::Polyline) &&
          "not a polygon or polyline");
   const auto points = attributes.points;
   assert(!points.empty() > 0 && "no points");
@@ -522,8 +674,8 @@ bool SVG::SVGElement::has_all_points_equal() const {
 }
 
 bool SVG::SVGElement::has_clockwise_points() const {
-  assert((type == SVG::SVGElementType::Polygon ||
-          type == SVG::SVGElementType::Polyline) &&
+  assert((elem_type == SVG::SVGElementType::Polygon ||
+          elem_type == SVG::SVGElementType::Polyline) &&
          "not a polygon or polyline");
   assert(attributes.points.size() >= 3 && "too few points");
   // Sum over the edges, (x2 − x1)(y2 + y1). If the result is positive, the
@@ -547,7 +699,7 @@ std::string SVG::SVGElement::fill_attribute_to_string() const {
     return "";
   }
 
-  return fmt::format(R"(fill="{}")", to_graphviz_color(attributes.fill));
+  return std::format(R"(fill="{}")", to_graphviz_color(attributes.fill));
 }
 
 std::string SVG::SVGElement::id_attribute_to_string() const {
@@ -555,7 +707,7 @@ std::string SVG::SVGElement::id_attribute_to_string() const {
     return "";
   }
 
-  return fmt::format(R"(id="{}")", attributes.id);
+  return std::format(R"(id="{}")", attributes.id);
 }
 
 std::string SVG::SVGElement::fill_opacity_attribute_to_string() const {
@@ -570,14 +722,14 @@ std::string SVG::SVGElement::fill_opacity_attribute_to_string() const {
     return "";
   }
 
-  return fmt::format(R"(fill-opacity="{}")", attributes.fill_opacity);
+  return std::format(R"(fill-opacity="{}")", attributes.fill_opacity);
 }
 
 std::string SVG::SVGElement::points_attribute_to_string() const {
   std::string points_attribute_str = R"|(points=")|";
   const char *separator = "";
   for (const auto &point : attributes.points) {
-    points_attribute_str += separator + fmt::format("{},{}", point.x, point.y);
+    points_attribute_str += separator + std::format("{},{}", point.x, point.y);
     separator = " ";
   }
   points_attribute_str += '"';
@@ -590,7 +742,7 @@ std::string SVG::SVGElement::stroke_attribute_to_string() const {
     return "";
   }
 
-  return fmt::format(R"(stroke="{}")",
+  return std::format(R"(stroke="{}")",
                      stroke_to_graphviz_color(attributes.stroke));
 }
 
@@ -606,7 +758,7 @@ std::string SVG::SVGElement::stroke_opacity_attribute_to_string() const {
     return "";
   }
 
-  return fmt::format(R"(stroke-opacity="{}")", attributes.stroke_opacity);
+  return std::format(R"(stroke-opacity="{}")", attributes.stroke_opacity);
 }
 
 std::string SVG::SVGElement::stroke_width_attribute_to_string() const {
@@ -615,7 +767,7 @@ std::string SVG::SVGElement::stroke_width_attribute_to_string() const {
     return "";
   }
 
-  return fmt::format(R"(stroke-width="{}")", attributes.stroke_width);
+  return std::format(R"(stroke-width="{}")", attributes.stroke_width);
 }
 
 std::string SVG::SVGElement::to_string(std::size_t indent_size = 2) const {
@@ -626,7 +778,7 @@ std::string SVG::SVGElement::to_string(std::size_t indent_size = 2) const {
             "\n";
   output += R"( "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd">)"
             "\n";
-  output += fmt::format("<!-- Generated by graphviz version {} "
+  output += std::format("<!-- Generated by graphviz version {} "
                         "({})\n -->\n",
                         graphviz_version, graphviz_build_date);
   to_string_impl(output, indent_size, 0);
@@ -639,22 +791,22 @@ void SVG::SVGElement::to_string_impl(std::string &output,
   const auto indent_str = std::string(current_indent, ' ');
   output += indent_str;
 
-  if (type == SVG::SVGElementType::Svg) {
-    const auto comment = fmt::format("Title: {} Pages: 1", graphviz_id);
-    output += fmt::format("<!-- {} -->\n", xml_encode(comment));
+  if (elem_type == SVG::SVGElementType::Svg) {
+    const auto comment = std::format("Title: {} Pages: 1", graphviz_id);
+    output += std::format("<!-- {} -->\n", xml_encode(comment));
   }
-  if (type == SVG::SVGElementType::Group &&
+  if (elem_type == SVG::SVGElementType::Group &&
       (attributes.class_ == "node" || attributes.class_ == "edge")) {
     const auto comment = graphviz_id;
-    output += fmt::format("<!-- {} -->\n", xml_encode(comment));
+    output += std::format("<!-- {} -->\n", xml_encode(comment));
   }
 
   output += "<";
-  output += tag(type);
+  output += tag(elem_type);
 
   std::string attributes_str{};
   append_attribute(attributes_str, id_attribute_to_string());
-  switch (type) {
+  switch (elem_type) {
   case SVG::SVGElementType::Ellipse:
     append_attribute(attributes_str, fill_attribute_to_string());
     append_attribute(attributes_str, fill_opacity_attribute_to_string());
@@ -662,14 +814,14 @@ void SVG::SVGElement::to_string_impl(std::string &output,
     append_attribute(attributes_str, stroke_width_attribute_to_string());
     append_attribute(attributes_str, stroke_opacity_attribute_to_string());
     attributes_str +=
-        fmt::format(R"( cx="{}" cy="{}" rx="{}" ry="{}")", attributes.cx,
+        std::format(R"( cx="{}" cy="{}" rx="{}" ry="{}")", attributes.cx,
                     attributes.cy, attributes.rx, attributes.ry);
     break;
   case SVG::SVGElementType::Group:
-    attributes_str += fmt::format(R"( class="{}")", attributes.class_);
+    attributes_str += std::format(R"( class="{}")", attributes.class_);
     if (attributes.transform.has_value()) {
       const auto transform = attributes.transform;
-      attributes_str += fmt::format(
+      attributes_str += std::format(
           R"|( transform="scale({} {}) rotate({}) translate({} {})")|",
           transform->a, transform->d, transform->c, transform->e, transform->f);
     }
@@ -683,7 +835,7 @@ void SVG::SVGElement::to_string_impl(std::string &output,
     attributes_str += R"|( d=")|";
     auto command = 'M';
     for (const auto &point : path_points) {
-      attributes_str += fmt::format("{}{},{}", command, point.x, point.y);
+      attributes_str += std::format("{}{},{}", command, point.x, point.y);
       switch (command) {
       case 'M':
         command = 'C';
@@ -717,7 +869,7 @@ void SVG::SVGElement::to_string_impl(std::string &output,
     break;
   case SVG::SVGElementType::Rect:
     attributes_str +=
-        fmt::format(R"(x="{}" y="{}" width="{}" height="{}")", attributes.x,
+        std::format(R"(x="{}" y="{}" width="{}" height="{}")", attributes.x,
                     attributes.y, attributes.width, attributes.height);
     append_attribute(attributes_str, fill_attribute_to_string());
     append_attribute(attributes_str, stroke_attribute_to_string());
@@ -725,7 +877,7 @@ void SVG::SVGElement::to_string_impl(std::string &output,
     append_attribute(attributes_str, stroke_opacity_attribute_to_string());
     break;
   case SVG::SVGElementType::Svg:
-    attributes_str += fmt::format(
+    attributes_str += std::format(
         R"(width="{}pt" height="{}pt")"
         "\n"
         R"( viewBox="{:.2f} {:.2f} {:.2f} {:.2f}" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink")",
@@ -735,8 +887,8 @@ void SVG::SVGElement::to_string_impl(std::string &output,
         attributes.viewBox.height);
     break;
   case SVG::SVGElementType::Text:
-    attributes_str += fmt::format(
-        R"(text-anchor="{}" x="{}" y="{}" font-family="{}" font-size="{:.2f}")",
+    attributes_str += std::format(
+        R"(xml:space="preserve" text-anchor="{}" x="{}" y="{}" font-family="{}" font-size="{:.2f}")",
         attributes.text_anchor, attributes.x, attributes.y,
         attributes.font_family, attributes.font_size);
     break;
@@ -744,8 +896,8 @@ void SVG::SVGElement::to_string_impl(std::string &output,
     // Graphviz doesn't generate attributes on 'title' elements
     break;
   default:
-    throw std::runtime_error{fmt::format(
-        "Attributes on '{}' elements are not yet implemented", tag(type))};
+    throw std::runtime_error{std::format(
+        "Attributes on '{}' elements are not yet implemented", tag(elem_type))};
   }
   if (!attributes_str.empty()) {
     output += " ";
@@ -767,17 +919,17 @@ void SVG::SVGElement::to_string_impl(std::string &output,
       output += indent_str;
     }
     output += "</";
-    output += tag(type);
+    output += tag(elem_type);
     output += ">\n";
   }
 }
 
-SVG::SVGPoint
-SVG::SVGElement::miter_point(SVG::SVGPoint segment_start,
+SVG::SVGPoints
+SVG::SVGElement::miter_shape(SVG::SVGPoint segment_start,
                              SVG::SVGPoint segment_end,
                              SVG::SVGPoint following_segment_end) const {
   /*
-   * Compute the stroke shape miter point according to
+   * Compute the stroke shape miter shape according to
    * https://www.w3.org/TR/SVG2/painting.html#StrokeShape.
    *
    * The spec assumes the points of a shape are given in clockwise
@@ -841,7 +993,7 @@ SVG::SVGElement::miter_point(SVG::SVGPoint segment_start,
    *     NOTE: In the diagram above, the B segment crosses the x-axis in the
    *           downwards direction so its angle to the x-axis is in this case
    *           larger than a semi-circle (π or 180°). In the picture it is
-   *           around 5π/6 or 300°. The B segement in the opposite direction has
+   *           around 5π/3 or 300°. The B segment in the opposite direction has
    *           an angle to the x-axis which is β-π. This is denoted next to the
    *           Bleft line in the picture.
    *
@@ -859,7 +1011,7 @@ SVG::SVGElement::miter_point(SVG::SVGPoint segment_start,
     // the stroke shape is really a point so we just return this point without
     // extending it with stroke width in any direction, which seems to be the
     // way SVG renderers render this.
-    return segment_end;
+    return {segment_end};
   }
 
   const auto stroke_width = attributes.stroke_width;
@@ -887,29 +1039,30 @@ SVG::SVGElement::miter_point(SVG::SVGPoint segment_start,
   const auto cosBeta = dxB / hypotB;
   const auto beta = dyB > 0 ? std::acos(cosBeta) : -std::acos(cosBeta);
 
+  const auto sinBeta = dyB / hypotB;
+  const auto sinBetaMinusPi = -sinBeta;
+  const auto cosBetaMinusPi = -cosBeta;
+  const SVG::SVGPoint P2 = {P.x + stroke_width / 2.0 * sinBetaMinusPi,
+                            P.y - stroke_width / 2.0 * cosBetaMinusPi};
+
   // angle between the A segment and the B segment in the reverse direction
   const auto beta_rev = beta - std::numbers::pi;
   const auto theta = beta_rev - alpha;
 
+  SVG::SVGPoints line_join_shape;
   const auto miter_limit = 4.0;
   const auto miter_length = stroke_width / std::sin(std::abs(theta) / 2.0);
 
+  // add the bevel, which is is the triangle formed from the three points P, P1
+  // and P2, to the line join shape. SVG has inverted y axis so invert the
+  // returned y value
+  line_join_shape.emplace_back(P.x, -P.y);
+  line_join_shape.emplace_back(P1.x, -P1.y);
+  line_join_shape.emplace_back(P2.x, -P2.y);
+
   if (miter_length > miter_limit * stroke_width) {
-    // fall back to bevel
-    const auto sinBeta = dyB / hypotB;
-    const auto sinBetaMinusPi = -sinBeta;
-    const auto cosBetaMinusPi = -cosBeta;
-    const SVG::SVGPoint P2 = {P.x + stroke_width / 2.0 * sinBetaMinusPi,
-                              P.y - stroke_width / 2.0 * cosBetaMinusPi};
-
-    // the bevel is the triangle formed from the three points P, P1 and P2 so
-    // a good enough approximation of the miter point in this case is the
-    // crossing of P-P3 with P1-P2 which is the same as the midpoint between
-    // P1 and P2
-    const SVG::SVGPoint Pbevel = {(P1.x + P2.x) / 2, (P1.y + P2.y) / 2};
-
-    // SVG has inverted y axis so invert the returned y value
-    return {Pbevel.x, -Pbevel.y};
+    // fall back to bevel only
+    return line_join_shape;
   }
 
   // length between P1 and P3 (and between P2 and P3)
@@ -918,7 +1071,8 @@ SVG::SVGElement::miter_point(SVG::SVGPoint segment_start,
   const SVG::SVGPoint P3 = {P1.x + l * cosAlpha, P1.y + l * sinAlpha};
 
   // SVG has inverted y axis so invert the returned y value
-  return {P3.x, -P3.y};
+  line_join_shape.emplace_back(P3.x, -P3.y);
+  return line_join_shape;
 }
 
 std::string
@@ -967,8 +1121,8 @@ void SVG::SVGRect::extend(const SVG::SVGRect &other) {
   height = ymax - ymin;
 }
 
-std::string_view SVG::tag(SVGElementType type) {
-  switch (type) {
+std::string_view SVG::tag(SVGElementType elem_type) {
+  switch (elem_type) {
   case SVG::SVGElementType::Circle:
     return "circle";
   case SVG::SVGElementType::Ellipse:
